from random import Random
import typing

import time
import json

from lctest.lib import linked_list_to_array
from lctest.text_format import textformat


def audit(text=''):
    global t0
    if text:
        runtime = (time.time() - t0) * 1000
        print(f"{text}: {'%.6f' % runtime} ms")
    t0 = time.time()


def linked_list_result_to_array(fun):
    def wrapper(*args, **kwargs):
        head = fun(*args, **kwargs)
        return linked_list_to_array(head)

    return wrapper


def list_node_to_value(fun):
    def wrapper(*args, **kwargs):
        node = fun(*args, **kwargs)

        return node.val if node else None

    return wrapper


def sort_result(fun):
    def wrapper(*args, **kwargs):
        arr = fun(*args, **kwargs)
        return sorted(arr)

    return wrapper


def run(times=1):
    def deco(fun):
        import inspect
        has_parameter = len(inspect.signature(fun).parameters) > 0

        def wrapper():
            print(textformat(f"Running <green><bold>{fun.__name__}</>"))
            for i in range(times):
                print(f"<gray>---------#{i + 1}---------</c>")
                args = [i] if has_parameter else []
                fun(*args)

        return wrapper()

    return deco


def measure(fun, *args):
    t0 = time.time()
    result = fun(*args)
    run_time = time.time() - t0
    return run_time, result


def random_list(size, min_value, max_value=1000, seed=None, is_sorted=False):
    if isinstance(min_value, typing.Iterable):
        space = list(min_value)
        min_value = 0
        max_value = len(space) - 1
    else:
        space = None

    r = Random(seed) if seed is not None else Random()
    arr = [r.randint(min_value, max_value) for _ in range(size)]
    if space:
        arr = [space[i] for i in arr]
    return sorted(arr) if is_sorted else arr


def random_matrix(row, col, min_value, max_value, seed=None):
    r = Random(seed) if seed is not None else Random()
    return [
        [r.randint(min_value, max_value) for _ in range(col)]
        for _ in range(row)
    ]


def print_json(obj, indent=4):
    print(json.dumps(obj, indent=indent))



import re

_text_formats = ['b', 'f', 'i', 'u']
_dark_colors = ["black", "red", "green", "yellow", "blue", "magenta", "cyan", "gray"]
_light_colors = ["brightblack", "brightred", "brightgreen", "brightyellow", "brightblue",
                 "brightmagenta", "brightcyan", "white"]


def _code(number):
    return f"\x1b[{number:02d}m"


_codes = {
    "</t>": _code(0),  # End text format
    "</c>": _code(39),  # End foreground color
    "</b>": _code(49),  # End background color
    "</>": _code(0) + _code(39) + _code(49) # End for all
}

for i, text_format in enumerate(_text_formats):
    _codes[f"<{text_format}>"] = _code(i + 1)

for i, (dark, light) in enumerate(list(zip(_dark_colors, _light_colors))):
    _codes[f"<{dark}>"] = _code(i + 30)
    _codes[f"<{light}>"] = _code(i + 90)

    _codes[f"<b:{dark}>"] = _code(i + 40)
    _codes[f"<b:{light}>"] = _code(i + 100)


def textformat(template, enabled=True):
    arr = re.split(r"(<.+?>)", template)
    for i, text in enumerate(arr):
        if text in _codes:
            arr[i] = _codes[text] if enabled else ""
    return "".join(arr)


if __name__ == '__main__':
    print(textformat("<b><b:red>home</b></c> is</t> <i>a <green>place</c> to <b><u>sleep</t>"))
    print(textformat("<b><b:red>home</b></c> is</t> <i>a <green>place</c> to <b><u>sleep</t>", enabled=False))



class ListNode:
    def __init__(self, x, next=None):
        self.val = x
        self.next = next

    def __str__(self):
        arr = []
        cur = self
        circle_at = None
        while cur:
            if cur in arr:
                circle_at = cur
                break
            arr.append(cur)
            cur = cur.next
        values = list(map(lambda x: x.val, arr))
        if circle_at:
            return f"{values} ○ {arr.index(circle_at)}|{circle_at.val}"
        else:
            return f"{values}"


class TreeNode:
    def __init__(self, val, left=None, right=None):
        self.val = val
        self.left = left
        self.right = right

    def __str__(self):
        arr = []

        def dfs(node: TreeNode):
            if not node:
                arr.append(None)
                return
            arr.append(node.val)
            if not node.left and not node.right:
                return
            dfs(node.left)
            dfs(node.right)

        dfs(self)
        return str(arr)


def linked_list(*arr, tail=None) -> ListNode:
    dummy = ListNode(0)
    last = dummy
    for item in arr:
        node = ListNode(item)
        last.next = node
        last = last.next

    if tail is not None:
        last.next = dummy.next
        while tail > 0:
            last.next = last.next.next
            tail -= 1

    return dummy.next


def tree2(*arr) -> TreeNode:
    """
    :param arr: Format: Same format as Leetcode
    :return:
    """

    if not arr:
        raise Exception()

    def standardize(arr):
        rows = [(arr[0],)]
        index = 1
        while index < len(arr):
            cur = rows[-1]
            valid_count = len(cur) - cur.count(None)
            next_row = arr[index:index + valid_count * 2]
            for i, v in enumerate(cur):
                if v is None:
                    next_row = next_row[:2 * i] + (None, None) + next_row[2 * i:]
            index += valid_count * 2
            rows.append(next_row)
        res = []
        for row in rows:
            res += row
        return res

    arr = standardize(arr)
    values = list(arr)
    root = TreeNode(values.pop(0))
    level = [root]

    def accept(node: TreeNode):
        return node if node.val is not None else None

    while values:
        items_left = len(values)
        required_items = len(level) * 2
        if items_left < required_items:
            values += [None] * (required_items - items_left)
        nodes = [TreeNode(v) for v in values[:required_items]]

        for i, n in enumerate(level):
            n.left = accept(nodes[i * 2])
            n.right = accept(nodes[i * 2 + 1])

        level = nodes

        values = values[required_items:]

    return root


class LoopError(Exception):
    def __init__(self, item):
        self.loop_item = item

    def __str__(self):
        return "Loop with %s" % self.loop_item.val


def linked_list_to_array(head):
    """
    :param head: NodeList
    :return: list
    """
    read_set = set()
    result = []
    first = head
    while first:
        if first in read_set:
            raise LoopError(first)
        read_set.add(first)
        result.append(first.val)
        first = first.next
    return result


def print_linked_list(head):
    if not head:
        print("Empty")
    first = head
    while first is not None:
        print("> %s" % first.val)
        first = first.next


def print_table(table):
    max_length = 0
    for row in table:
        for item in row:
            max_length = max(max_length, len(str(item)))

    format_str = "%" + str(max_length + 2) + "s"
    for row in table:
        print("".join([format_str % item for item in row]))
    print()


def print_json(obj):
    import json
    print(json.dumps(obj, indent=4))



from traceback import TracebackException

from lctest.text_format import textformat

try:
    # noinspection PyUnresolvedReferences
    from StringIO import StringIO
except:
    from io import StringIO
import sys
import time
import copy
import inspect

NO_RUN = 'no_run'
SOLUTION = 'solution'
TESTCASES = 'testcases'

sys.setrecursionlimit(50000)


def skip_test(fun):
    """
    Adds flag no_run to ignore executing a function for `@testcase`.
    Use this right under `@testcase` or for test method (`solXxx`)
    """

    def wrapper(*args, **kwargs):
        return fun(*args, **kwargs)

    wrapper.__dict__[NO_RUN] = True
    return wrapper


def solution(fun):
    def wrapper(*args, **kwargs):
        return fun(*args, **kwargs)

    wrapper.__dict__[SOLUTION] = True
    return wrapper


def log(*args):
    """
    Shorthand to create a testcase with log turned on.
    """
    return Testcase(args, is_log=True)

def skip_result(*args):
    """
    Shorthand to create a testcase that skips printing result.
    Mainly for measuring the performance.
    """
    return Testcase(args, print_result=False)


def testcase(*testcases, log=False, param_length_limit=100):
    is_printable = log or len(testcases) == 1
    if param_length_limit == -1:
        param_length_limit = float('inf')

    def deco(target):
        if inspect.isclass(target):
            deco_class(target)
        else:
            return deco_fun(target)

    def deco_fun(fun):
        def wrapper():
            execute(fun, testcases)

        is_class_method = 'self' in inspect.signature(fun).parameters
        if is_class_method or NO_RUN in fun.__dict__:
            fun.__dict__[TESTCASES] = testcases
            return fun

        print(textformat(f"<cyan>Test result for</c> <blue><b>{fun.__name__}</>"))
        return wrapper()

    def deco_class(cls):
        def wrapper():
            for fun_name, testcases in get_runnable_methods_and_testcases():
                obj = cls()
                print(textformat(f"<b:brightblack>Test result for</> <b><i>{cls.__name__}</>.<brightmagenta><b>{fun_name}</>"))
                execute(obj.__getattribute__(fun_name), testcases)

        def get_runnable_methods_and_testcases():
            runnable_method_names_and_testcases = []

            obj = cls()
            for name in obj.__dir__():
                fun = obj.__getattribute__(name)
                if not name.startswith('sol') and SOLUTION not in dir(fun):
                    continue

                attributes = dir(fun)

                if NO_RUN in attributes or not callable(fun):
                    continue
                cases = testcases if TESTCASES not in attributes else fun.__getattribute__(TESTCASES)
                runnable_method_names_and_testcases.append((name, cases))

            return runnable_method_names_and_testcases

        if NO_RUN in dir(cls):
            return cls
        return wrapper()

    def execute(fun, testcases):
        is_method_printable = is_printable
        helper = TestHelper(testcases, is_method_printable, param_length_limit)

        for case in helper.testcases:
            printer = helper.create_case_helper(case)

            try:
                t0 = time.time()
                result = fun(*case.params_snapshot)
                runtime = (time.time() - t0) * 1000
                printer.print_result(result, runtime)
            except KeyboardInterrupt:
                raise
            except:
                printer.print_error()

    return deco


class _TestPrinter:
    def __init__(self, params_text, params, expected, is_test_printable, is_result_printable):
        self.params_text = params_text
        self.params = params
        self.expected = expected
        self.is_test_printable = is_test_printable
        self.is_result_printable = is_result_printable

        self.output = StringIO()

        if not is_test_printable:
            sys.stdout = self.output
        else:
            # Use gray color for log
            print(textformat("<gray><f>▼"))

    def print_result(self, result, runtime):
        sys.stdout = sys.__stdout__
        # Reset gray color of log
        print(textformat("</>"), end="")

        is_correct, formatted_result, formatted_expected = self._result_to_text(result)
        if not self.is_result_printable:
            formatted_result = textformat("<brightblack>[result is hidden]</c>")

        arrow = self._format(is_correct, '➜', '➜', '➜') if not callable(self.expected) else self._format(is_correct,
                                                                                                         '»', '»', '»')
        check = self._format(is_correct, '✔✔', '𐄂𐄂', '⚑⚑')

        runtime_text = textformat(f"<f><i>{runtime:.3f}ms</>")
        print(self.params_text, arrow, formatted_result, check, runtime_text)

        if is_correct is not None and not is_correct:
            expected_title = 'Expected:'
            space = " " * (len(self.params_text) + 2 - len(expected_title))
            print(textformat(f"{space}<gray>{expected_title} {formatted_expected}</c>"))

        if is_correct is None or not is_correct:
            print_log = self.output.getvalue()
            if print_log:
                print(textformat(f"<brightyellow>{str(print_log)}</c>"))
            else:
                pass
        self.output.close()

    def _result_to_text(self, result):
        result_text = str(result)
        if self.expected is None:
            return None, result_text, ""
        if result == self.expected:
            return True, result_text, result_text

        if callable(self.expected):
            expected = self.expected(*self.params)
            expected_text = str(expected)
        else:
            expected = self.expected
            expected_text = str(self.expected)

        result_arr = []
        expected_arr = []
        length = min(len(result_text), len(expected_text))
        for i in range(length):
            is_equal = result_text[i] == expected_text[i]
            result_arr.append(textformat(f"<red>{result_text[i]}</c>", enabled=not is_equal))
            expected_arr.append(textformat(f"<red>{expected_text[i]}</c>", enabled=not is_equal))
        if length < len(result_text):
            result_arr.append(textformat(f"<red>{result_text[length:]}</c>"))
        else:
            expected_arr.append(f"<red>{expected_text[length:]}</c>")
        return expected == result, "".join(result_arr), "".join(expected_arr)

    @staticmethod
    def _format(is_correct, correct, wrong, unknown):
        if is_correct is None:
            return textformat(f"<yellow>{unknown}</c>")
        elif is_correct:
            return textformat(f"<green>{correct}</c>")
        else:
            return textformat(f"<red>{wrong}</c>")

    def print_error(self):
        print_log = self.output.getvalue().strip()
        sys.stdout = sys.__stdout__
        print(self.params_text)
        if print_log:
            print(print_log)
        exec_info = sys.exc_info()
        traceback_lines = list(TracebackException(*exec_info).format())
        trimmed_traceback_lines = []
        for line in traceback_lines[::-1]:
            if "test/testcase.py" in line:
                break
            if len(trimmed_traceback_lines) > 5:
                break
            trimmed_traceback_lines.insert(0, line)
        for line in trimmed_traceback_lines:
            print(textformat(f"<red>{line}</c>"), end="")
        print()


class TestHelper:

    def __init__(self, testcases, is_test_printable, param_length_limit):
        self.testcases = [tc if isinstance(tc, Testcase) else Testcase(tc) for tc in testcases]
        self.param_length_limit = param_length_limit
        self.param_format = self._build_format()
        self.is_test_printable = is_test_printable

    def _build_format(self):
        param_count = len(self.testcases[0].params)
        param_lengths = [0] * param_count

        for case in self.testcases:
            for i, param in enumerate(case.params):
                str_param = str(param)
                param_lengths[i] = min(max(param_lengths[i], len(str_param)), self.param_length_limit)

        total_space = sum(param_lengths) + 4 * (len(param_lengths) - 1)
        prefix = " " * (8 - total_space)
        param_formats = [f"{prefix}%{length}s" for length in param_lengths]

        return "    ".join(param_formats)

    def create_case_helper(self, testcase):
        param_texts = [str(param) for param in testcase.params]
        for i, text in enumerate(param_texts):
            param_texts[i] = text if len(text) < self.param_length_limit else text[:self.param_length_limit - 3] + "..."

        params_text = self.param_format % tuple(param_texts)
        is_case_loggable = self.is_test_printable or testcase.is_loggable
        return _TestPrinter(params_text, testcase.params, testcase.expected, is_case_loggable, testcase.print_result)


class Testcase:
    def __init__(self, args, is_log=False, print_result=True):
        self.expected = args[0]
        self.params = args[1:]
        self.is_loggable = is_log
        self.print_result = print_result

    @property
    def params_snapshot(self):
        return copy.deepcopy(self.params)



def read_int():
    # noinspection PyGlobalUndefined
    global this_variable_is_keeping_inputs
    try:
        this_variable_is_keeping_inputs = this_variable_is_keeping_inputs
    except:
        this_variable_is_keeping_inputs = None
    if not this_variable_is_keeping_inputs:
        this_variable_is_keeping_inputs = input().strip().split(' ')[::-1]
    return int(this_variable_is_keeping_inputs.pop())


if __name__ == '__main__':
    '''
5 5
5 4 2 3 5
2 0 3
1 1 1
2 0 3
1 3 1
2 0 5
    '''
    m = read_int()
    n = read_int()
    print(m, n)

    arr = [read_int() for _ in range(m)]
    print(arr)
    for i in range(n):
        row = [read_int(), read_int(), read_int()]
        print(row)



from lctest.testcase import testcase, skip_test, log, skip_result, solution
from lctest.test import \
    random_list, \
    random_matrix, \
    linked_list_result_to_array, \
    linked_list_to_array, \
    list_node_to_value, \
    audit, \
    sort_result, \
    run, \
    measure, \
    print_json
from lctest.lib import \
    ListNode, \
    TreeNode, \
    linked_list, \
    linked_list_to_array, \
    print_linked_list, \
    print_table, \
    tree2

from lctest.arguments import read_int



from collections import deque, defaultdict, Counter
from functools import lru_cache, reduce
from math import ceil, gcd, factorial
from itertools import chain, product, accumulate, combinations
from heapq import heappop, heappush, heapify
from bisect import bisect_left, bisect_right
from string import digits, ascii_lowercase
from math import inf